write — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# write

poscar_modify.write(filename: str, cartesian: bool = False, xyz: bool = False)

  Writes the content of this class into a file. It just invokes the write method from the Poscar class. Is here just for convenience.

  Parameters:

    - filename (str) – the name of the file to be written

    - cartesian (bool:) – Cartesian (True) or direct (False) coordinates. Default is True

    - xyz (bool) – should a xyz be written too? The ‘.xyz’ extension will be added automatically to filename Default is False.